==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicToolTipUI__241.h <==
// final class javax.swing.plaf.basic.BasicToolTipUI$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ce6943774c1020ac javax_swing_plaf_basic_BasicToolTipUI__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolTipUI__241_H_
#define _JC_javax_swing_plaf_basic_BasicToolTipUI__241_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_refs	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$refs	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$nonrefs	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vmethods	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtable	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicToolTipUI__241$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *, struct _jc_java_awt_Component$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *, struct _jc_java_awt_Component$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vmethods	javax_swing_plaf_basic_BasicToolTipUI__241;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$refs {
    _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_refs	javax_swing_plaf_basic_BasicToolTipUI__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_nonrefs	javax_swing_plaf_basic_BasicToolTipUI__241;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object {
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype _jc_javax_swing_plaf_basic_BasicToolTipUI__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolTipUI__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolTipUI__241$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolTipUI__241_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicToolTipUI__241.h <==
// final class javax.swing.plaf.basic.BasicToolTipUI$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ce6943774c1020ac javax_swing_plaf_basic_BasicToolTipUI__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolTipUI__241_H_
#define _JC_javax_swing_plaf_basic_BasicToolTipUI__241_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_refs	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$refs	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$nonrefs	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vmethods	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtable	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicToolTipUI__241$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolTipUI__241$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vmethods	javax_swing_plaf_basic_BasicToolTipUI__241;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$refs {
    _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_refs	javax_swing_plaf_basic_BasicToolTipUI__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolTipUI__241$sub_nonrefs	javax_swing_plaf_basic_BasicToolTipUI__241;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolTipUI__241$object {
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolTipUI__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolTipUI__241$vtype _jc_javax_swing_plaf_basic_BasicToolTipUI__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolTipUI__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolTipUI__241$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolTipUI__241_H_ */
